api.sensors.v1 package — Argus-Toolbelt 1.0 documentation

# api.sensors.v1 package

## Submodules

## api.sensors.v1.sensor module

Autogenerated API

`api.sensors.v1.sensor.` `find_sensors`(limit: int = None, offset: int = None, customerID: list = None, keywords: list = None, sortBy: list = None, startTimestamp: int = None, endTimestamp: int = None, includeFlags: list = None, excludeFlags: list = None, sensorID: list = None, locationName: list = None, applicationName: list = None, subCriteria: list = None, includeDeleted: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Search sensors (PUBLIC)

  Return type: | `dict`
  Parameters: | limit (int) – Limit results offset (int) – Offset results customerID (list) – Limit result to objects belonging to these customers keywords (list) – Search for sensors matching this hostname or IP-address sortBy (list) – Order results by these properties (prefix with - to sort descending) startTimestamp (int) – Search objects from this timestamp endTimestamp (int) – Search objects until this timestamp includeFlags (list) – Search objects with these flags set excludeFlags (list) – Exclude objects with these flags set sensorID (list) – Search for specific sensors by ID locationName (list) – Search for sensors bound to any of these locations applicationName (list) – Search for sensors by application type subCriteria (list) – includeDeleted (bool) – Also include deleted objects (where implemented)
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 383, “limit”: 693, “responseCode”: 200, “count”: 923, “data”: [{“id”: 443, “expectedUpdateTime”: 620, “scheduledDowntimeFromTime”: 474, “scheduledDowntimeUntilTime”: 185, “information”: “Why bring health center yard cell program.”, “hostname”: “Seek feel large suggest receive safe him.”, “additionalData”: “Modern why among require its.”, “flags”: [“ACKNOWLEDGED”], “lastUpdatedByUser”: {“id”: 209, “customerID”: 784, “userName”: “tannerbrett”, “name”: “Debra Lawrence”}, “lastUpdatedTimestamp”: 922866972, “lastAcknowledgedTimestamp”: 75635449, “inScheduledDowntime”: true}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Republican Mrs level loss work trade significant eye.”, “messageTemplate”: “Ready anyone raise field benefit.”, “field”: “Threat economy paper message between day.”, “parameter”: {}, “timestamp”: 583786703}], “currentPage”: 351, “size”: 90}

`api.sensors.v1.sensor.` `get_sensor`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch sensor by ID (PUBLIC)

  Return type: | `dict`
  Parameters: | id (int) – ID of sensor to fetch
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 391, “limit”: 146, “responseCode”: 200, “count”: 289, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Travel until account far contain consider develop.”, “messageTemplate”: “Particular time evidence themselves simple impact.”, “field”: “Nice manage before subject food himself huge.”, “parameter”: {}, “timestamp”: 958747246}], “currentPage”: 53, “size”: 755}

`api.sensors.v1.sensor.` `get_sensor_comments`(sensorID: int, limit: int = 25, offset: int = 0, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch sensor comments by sensor ID (PUBLIC)

  Return type: | `dict`
  Parameters: | sensorID (int) – ID of sensor to fetch comments for limit (int) – Limit results offset (int) – Offset results
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 346, “limit”: 566, “responseCode”: 200, “count”: 958, “data”: [{“timestamp”: 1169411591, “user”: {“id”: 596, “customerID”: 313, “userName”: “gonzalezkaitlyn”, “name”: “Anthony Lee”}, “comment”: “Including nice card artist add option.”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Poor time bed.”, “messageTemplate”: “Onto dark institution listen between economic and.”, “field”: “Young be ball several federal arm.”, “parameter”: {}, “timestamp”: 761498814}], “currentPage”: 543, “size”: 139}

`api.sensors.v1.sensor.` `list_sensors`(customerID: list = None, applicationName: list = None, keywords: list = None, limit: int = 25, offset: int = 0, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List sensors (PUBLIC)

  Return type: | `dict`
  Parameters: | customerID (list) – Limit search to these customer IDs applicationName (list) – Limit search to these applications by name keywords (list) – Limit search by sensor hostname or IP address limit (int) – Limit results offset (int) – Offset results
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 436, “limit”: 754, “responseCode”: 200, “count”: 241, “data”: [{“id”: 975, “expectedUpdateTime”: 331, “scheduledDowntimeFromTime”: 56, “scheduledDowntimeUntilTime”: 573, “information”: “Treat itself actually station.”, “hostname”: “Sometimes stop free.”, “additionalData”: “Whom mind receive during hair everyone seem.”, “flags”: [“OVERRIDE_UPDATE_TIME”], “lastUpdatedByUser”: {“id”: 75, “customerID”: 937, “userName”: “jtucker”, “name”: “Heather Carpenter”}, “lastUpdatedTimestamp”: 360123135, “lastAcknowledgedTimestamp”: 1460829507, “inScheduledDowntime”: false}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Ok lead think general than.”, “messageTemplate”: “Lawyer significant man lay respond big it low.”, “field”: “Recognize everybody goal wear begin smile live.”, “parameter”: {}, “timestamp”: 1401288531}], “currentPage”: 232, “size”: 988}

## api.sensors.v1.status module

Autogenerated API

`api.sensors.v1.status.` `find_sensors`(limit: int = None, offset: int = None, customerID: list = None, keywords: list = None, sortBy: list = None, startTimestamp: int = None, endTimestamp: int = None, includeFlags: list = None, excludeFlags: list = None, sensorID: list = None, locationName: list = None, applicationName: list = None, subCriteria: list = None, includeDeleted: bool = 'False', excludeReportingSensors: bool = 'False', excludeSensorsInScheduledDowntime: bool = 'False', excludeSensorsInReportingCluster: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Search sensor status (PUBLIC)

  Return type: | `dict`
  Parameters: | limit (int) – Limit results offset (int) – Offset results customerID (list) – Limit result to objects belonging to these customers keywords (list) – Search for sensors matching this hostname or IP-address sortBy (list) – Order results by these properties (prefix with - to sort descending) startTimestamp (int) – Search objects from this timestamp endTimestamp (int) – Search objects until this timestamp includeFlags (list) – Search objects with these flags set excludeFlags (list) – Exclude objects with these flags set sensorID (list) – Search for specific sensors by ID locationName (list) – Search for sensors bound to any of these locations applicationName (list) – Search for sensors by application type subCriteria (list) – includeDeleted (bool) – Also include deleted objects (where implemented) excludeReportingSensors (bool) – Exclude sensors which are reporting excludeSensorsInScheduledDowntime (bool) – Exclude sensors which are in scheduled downtime excludeSensorsInReportingCluster (bool) – Exclude sensors which are member of a cluster where any member is reporting
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 55, “limit”: 350, “responseCode”: 200, “count”: 281, “data”: [{“lastEventTimestamp”: 327670603, “lastUpdateTimestamp”: 455004236, “messageRate”: 38, “lastAgentHost”: “Marriage meet knowledge.”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Region evening book region positive.”, “messageTemplate”: “Expert friend toward health several may evidence.”, “field”: “Nation hand than area later more nothing test.”, “parameter”: {}, “timestamp”: 595075513}], “currentPage”: 388, “size”: 363}

`api.sensors.v1.status.` `get_sensor`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Fetch sensor status by ID (PUBLIC)

  Return type: | `dict`
  Parameters: | id (int) – ID of sensor to fetch status for
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 186, “limit”: 406, “responseCode”: 200, “count”: 130, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Find behavior full statement more last since audience.”, “messageTemplate”: “Green adult vote any.”, “field”: “Move suffer degree center also down.”, “parameter”: {}, “timestamp”: 532985732}], “currentPage”: 151, “size”: 195}

`api.sensors.v1.status.` `list_sensors`(customerID: list = None, applicationName: list = None, keywords: list = None, offset: int = None, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List sensor status (PUBLIC)

  Return type: | `dict`
  Parameters: | customerID (list) – Limit search to these customer IDs applicationName (list) – Limit search to these applications by name keywords (list) – Limit search by sensor hostname or IP address offset (int) – Offset results limit (int) – Limit results
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 423, “limit”: 484, “responseCode”: 200, “count”: 894, “data”: [{“lastEventTimestamp”: 994478686, “lastUpdateTimestamp”: 888677726, “messageRate”: 474, “lastAgentHost”: “Difficult attorney learn anyone safe a.”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Reach discussion near box him hear section.”, “messageTemplate”: “Investment compare get heavy suddenly home seek.”, “field”: “Action eight common see.”, “parameter”: {}, “timestamp”: 220547604}], “currentPage”: 446, “size”: 344}

## Module contents